@@ -20,10 +20,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 #ifndef _FSTRCMP_H
 #define _FSTRCMP_H
 
-#define PARAMS(proto) proto
-
-typedef UV CHAR;
-
 double fstrcmp (const UV *__s1, int __l1, const UV *__s2, int __l2, double __minimum);
 
 #endif
